@@ -9,7 +9,7 @@ from dateutil import parser
 
 from cimsparql.query_support import combine_statements, unionize
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from cimsparql.model import CimModel
 
 as_type_able = [int, float, str, "Int64", "Int32", "Int16"]
@@ -22,8 +22,8 @@ python_type_map = {
     "dateTime": parser.parse,
 }
 
-uri_snmst = re.compile("^urn:snmst:#_")
-sparql_type_map = {"literal": str, "uri": lambda x: uri_snmst.sub("", x)}
+uri_snmst = re.compile("[^\\#]*(.\\#\\_)")
+sparql_type_map = {"literal": str, "uri": lambda x: uri_snmst.sub("", x) if x is not None else ""}
 
 
 class TypeMapperQueries:
@@ -103,7 +103,7 @@ class TypeMapper(TypeMapperQueries):
     def type_map(df: pd.DataFrame) -> Dict[str, Any]:
         df["type"] = df["type"].str.lower()
         d = df.set_index("sparql_type").to_dict("index")
-        return {k: python_type_map.get(v.get("type", "String")) for k, v in d.items()}
+        return {k: python_type_map.get(v.get("type", "string")) for k, v in d.items()}
 
     @staticmethod
     def prefix_map(df: pd.DataFrame) -> Dict[str, Any]:
@@ -111,7 +111,7 @@ class TypeMapper(TypeMapperQueries):
         df["comb"] = df["prefix"] + "#" + df["type"]
         df = df.drop_duplicates("comb")
         d2 = df.set_index("comb").to_dict("index")
-        return {k: python_type_map.get(v.get("type", "String")) for k, v in d2.items()}
+        return {k: python_type_map.get(v.get("type", "string")) for k, v in d2.items()}
 
     def get_map(self, client: CimModel) -> Dict[str, Any]:
         """Reads all metadata from the sparql backend & creates a sparql-type -> python type map
